import plotly as py
import plotly.graph_objects as go


class BarChart:
    def __init__(self, data):
        self.data = data

    def draw(self, barmode, filename):
        fig = go.Figure(
            data=[
                go.Bar(
                    name=element.get("name"),
                    x=element.get("x_axis"),
                    y=element.get("y_axis"),
                )
                for element in self.data
            ]
        )

        fig.update_layout(barmode=barmode)

        py.offline.plot(fig, filename=filename)



import plotly as py
import plotly.graph_objects as go


class LineChart:
    def __init__(self, data):
        self.data = data

    def draw(self, chart_name, filename):
        content = []
        for element in self.data:
            trace = go.Scatter(
                x=element.get("x_axis"),
                y=element.get("y_axis"),
                name=element.get("name"),
            )

            content.append(trace)

        layout = go.Layout(title=chart_name)

        fig = go.Figure(data=content, layout=layout)

        py.offline.plot(fig, filename=filename)



# coding: UTF-8


import openpyxl


class MyWorkbook(object):

    def __init__(self, name):
        self.name = name


    def criar(self):
        self.wb = openpyxl.Workbook()
        self.wb.save(self.name)


# coding: UTF-8


import requests
from fake_useragent import UserAgent

# import re


class Avaliator(object):
    def __init__(self, url):
        self.url = url

    def avaliate(self):
        # link_clearing = lambda arg: re.sub('[\n]', '', arg)

        # self.url = link_clearing(self.url)

        response = requests.head(self.url)

        if response.status_code != 404:
            return response.status_code

        else:
            raise ConnectionError

    def connect(self):
        useragent = UserAgent()

        headers = {
            "Referer": "{}".format(self.url),
            "User-Agent": "{}".format(str(useragent.random)),
        }

        response = requests.get(self.url, headers=headers)

        return response



"""
Design Pattern: Strategy
"""


class Context(object):
    def __init__(self, strategy):
        self._strategy = strategy

    def context_interface(self, data):
        self._strategy.send(data)




'''
Design Pattern: Singleton
'''

class Singleton(type):

  def __init__(cls, name, bases, attrs, **kwargs):
    super().__init__(name, bases, attrs)
    cls._instance = None

  def __call__(cls, *args, **kwargs):
    if cls._instance is None:
      cls._instance = super().__call__(*args, **kwargs)
    return cls._instance


import io
from setuptools import (
    setup,
    find_packages,
)  # pylint: disable=no-name-in-module,import-error


def dependencies(file):
    with open(file) as f:
        return f.read().splitlines()


with io.open("README.md", encoding="utf-8") as infile:
    long_description = infile.read()

setup(
    name="smith_the_crawler",
    packages=find_packages(exclude=("tests", "examples")),
    version="0.0.12-alpha",
    # license="MIT",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3 :: Only",
    ],
    python_requires=">=3.1",
    description="A webscraper with a sofisticated toolkit to scrap the world",
    long_description=long_description,
    long_description_content_type="text/markdown",
    download_url="https://github.com/VictorAlessander/Smith/archive/refs/tags/v0.0.12-alpha.tar.gz",
    author="Victor Alessander",
    author_email="victor.alessander.gr@gmail.com",
    url="https://github.com/VictorAlessander/Smith",
    keywords=[
        "crawler",
        "webscraping",
        "webscraper",
        "investments",
        "investment",
        "invest",
    ],
    install_requires=[
        "beautifulsoup4",
        "plotly",
        "requests",
        "pandas",
        "fake-useragent",
        "openpyxl",
    ],
    # install_requires=dependencies('requirements.txt'),
    # tests_require=dependencies("requirements-dev.txt"),
    include_package_data=True,
    # extras_require={"ipython": ["IPython==5.7.0", "ipywidgets==7.1.0",]},
)
